@@ -1,5 +1,3 @@
-package org.apache.maven.doxia.macro.manager;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,6 +16,7 @@ package org.apache.maven.doxia.macro.manager;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.doxia.macro.manager;
 
 import org.apache.maven.doxia.macro.Macro;
 
@@ -27,10 +26,7 @@ import org.apache.maven.doxia.macro.Macro;
  * @author <a href="mailto:jason@maven.org">Jason van Zyl</a>
  * @since 1.0
  */
-public interface MacroManager
-{
-    /** The Plexus lookup role. */
-    String ROLE = MacroManager.class.getName();
+public interface MacroManager {
 
     /**
      * Returns the MacroManager that corresponds to the given id.
@@ -40,7 +36,5 @@ public interface MacroManager
      * @throws org.apache.maven.doxia.macro.manager.MacroNotFoundException if no MacroManager could be found
      * for the given id.
      */
-    Macro getMacro( String id )
-        throws MacroNotFoundException;
-
+    Macro getMacro(String id) throws MacroNotFoundException;
 }
