@@ -1,5 +1,3 @@
-package org.apache.maven.doxia.markup;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,6 +16,7 @@ package org.apache.maven.doxia.markup;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.doxia.markup;
 
 /**
  * List of constants used by <code>Text</code> markup syntax.
@@ -25,10 +24,8 @@ package org.apache.maven.doxia.markup;
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
  * @since 1.0
  */
-@SuppressWarnings( "checkstyle:interfaceistype" )
-public interface TextMarkup
-    extends Markup
-{
+@SuppressWarnings("checkstyle:interfaceistype")
+public interface TextMarkup extends Markup {
     // ----------------------------------------------------------------------
     // Text separator characters
     // ----------------------------------------------------------------------
