@@ -1,5 +1,3 @@
-package org.apache.maven.doxia.parser.manager;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,6 +16,7 @@ package org.apache.maven.doxia.parser.manager;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.doxia.parser.manager;
 
 import org.apache.maven.doxia.parser.Parser;
 
@@ -27,10 +26,7 @@ import org.apache.maven.doxia.parser.Parser;
  * @author <a href="mailto:jason@maven.org">Jason van Zyl</a>
  * @since 1.0
  */
-public interface ParserManager
-{
-    /** The Plexus lookup role. */
-    String ROLE = ParserManager.class.getName();
+public interface ParserManager {
 
     /**
      * Returns the parser that corresponds to the given id.
@@ -40,6 +36,5 @@ public interface ParserManager
      * @throws org.apache.maven.doxia.parser.manager.ParserNotFoundException if no parser could be found
      * for the given id.
      */
-    Parser getParser( String id )
-        throws ParserNotFoundException;
+    Parser getParser(String id) throws ParserNotFoundException;
 }
