@@ -1,5 +1,3 @@
-package org.apache.maven.doxia.parser.module;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,6 +16,7 @@ package org.apache.maven.doxia.parser.module;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.doxia.parser.module;
 
 import java.util.Collection;
 
@@ -26,8 +25,7 @@ import java.util.Collection;
  *
  * @since 1.6
  */
-public interface ParserModuleManager
-{
+public interface ParserModuleManager {
     /**
      * Returns a collection of ParserModules.
      *
@@ -43,6 +41,5 @@ public interface ParserModuleManager
      * @throws ParserModuleNotFoundException if no ParserModule could be found
      * for the given id.
      */
-    ParserModule getParserModule( String id )
-        throws ParserModuleNotFoundException;
+    ParserModule getParserModule(String id) throws ParserModuleNotFoundException;
 }
