@@ -1,5 +1,3 @@
-package org.apache.maven.doxia.sink.impl;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,6 +16,7 @@ package org.apache.maven.doxia.sink.impl;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.doxia.sink.impl;
 
 import org.apache.maven.doxia.markup.TextMarkup;
 
@@ -26,10 +25,6 @@ import org.apache.maven.doxia.markup.TextMarkup;
  *
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
  */
-public abstract class AbstractTextSink
-    extends SinkAdapter
-    implements TextMarkup
-{
+public abstract class AbstractTextSink extends SinkAdapter implements TextMarkup {
     // nop
 }
-
