@@ -1,5 +1,3 @@
-package org.apache.maven.doxia.module.apt;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,13 +16,15 @@ package org.apache.maven.doxia.module.apt;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.doxia.module.apt;
+
+import javax.inject.Named;
+import javax.inject.Singleton;
 
 import java.io.Writer;
 
 import org.apache.maven.doxia.sink.Sink;
-import org.apache.maven.doxia.sink.SinkFactory;
 import org.apache.maven.doxia.sink.impl.AbstractTextSinkFactory;
-import org.codehaus.plexus.component.annotations.Component;
 
 /**
  * APT implementation of the Sink factory.
@@ -32,14 +32,12 @@ import org.codehaus.plexus.component.annotations.Component;
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
  * @since 1.0
  */
-@Component( role = SinkFactory.class, hint = "apt" )
-public class AptSinkFactory
-    extends AbstractTextSinkFactory
-{
+@Singleton
+@Named("apt")
+public class AptSinkFactory extends AbstractTextSinkFactory {
     /** {@inheritDoc} */
-    protected Sink createSink( Writer writer, String encoding )
-    {
+    protected Sink createSink(Writer writer, String encoding) {
         // encoding can safely be ignored since it isn't written into the generated APT source
-        return new AptSink( writer );
+        return new AptSink(writer);
     }
 }
