@@ -1,5 +1,3 @@
-package org.apache.maven.doxia.module.apt;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,20 +16,19 @@ package org.apache.maven.doxia.module.apt;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.doxia.module.apt;
 
 /**
  * An interface to read apt source documents.
  */
-public interface AptSource
-{
+public interface AptSource {
     /**
      * Returns a line of the apt source document.
      *
      * @return a line of the apt source.
      * @throws org.apache.maven.doxia.module.apt.AptParseException if the document can't be parsed.
      */
-    String getNextLine()
-        throws AptParseException;
+    String getNextLine() throws AptParseException;
 
     /**
      * Returns the name the apt source document.
@@ -47,4 +44,3 @@ public interface AptSource
      */
     int getLineNumber();
 }
-
