@@ -1,5 +1,3 @@
-package org.apache.maven.doxia.module.apt;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,6 +16,7 @@ package org.apache.maven.doxia.module.apt;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.doxia.module.apt;
 
 import java.io.Writer;
 
@@ -25,22 +24,18 @@ import org.apache.maven.doxia.module.AbstractIdentityTest;
 import org.apache.maven.doxia.parser.Parser;
 import org.apache.maven.doxia.sink.Sink;
 
-
 /**
  * Check that piping a full model through an AptParser and an AptSink
  * leaves the model unchanged. The test is done in AbstractIdentityTest.
  */
-public class AptIdentityTest extends AbstractIdentityTest
-{
+public class AptIdentityTest extends AbstractIdentityTest {
     /** {@inheritDoc} */
-    protected Sink createSink( Writer writer )
-    {
-        return new AptSink( writer );
+    protected Sink createSink(Writer writer) {
+        return new AptSink(writer);
     }
 
     /** {@inheritDoc} */
-    protected Parser createParser()
-    {
+    protected Parser createParser() {
         return new AptParser();
     }
 }
