@@ -1,5 +1,3 @@
-package org.apache.maven.doxia.module.xdoc;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,25 +16,25 @@ package org.apache.maven.doxia.module.xdoc;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.doxia.module.xdoc;
+
+import javax.inject.Named;
+import javax.inject.Singleton;
 
 import org.apache.maven.doxia.parser.module.AbstractParserModule;
-import org.apache.maven.doxia.parser.module.ParserModule;
-import org.codehaus.plexus.component.annotations.Component;
 
 /**
  * <p>XdocParserModule class.</p>
  *
  * @since 1.6
  */
-@Component( role = ParserModule.class, hint = "xdoc" )
-public class XdocParserModule
-    extends AbstractParserModule
-{
+@Singleton
+@Named("xdoc")
+public class XdocParserModule extends AbstractParserModule {
     /**
      * Default constructor.
      */
-    public XdocParserModule()
-    {
-        super( "xdoc", "xml" );
+    public XdocParserModule() {
+        super("xdoc", "xml");
     }
 }
