@@ -1,5 +1,3 @@
-package org.apache.maven.doxia.module.xhtml5;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,13 +16,11 @@ package org.apache.maven.doxia.module.xhtml5;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.doxia.module.xhtml5;
 
 import org.apache.maven.doxia.sink.impl.SinkAdapter;
 
 /**
  * <p>Abstract AbstractXhtml5Sink class.</p>
  */
-public abstract class AbstractXhtml5Sink
-    extends SinkAdapter
-{
-}
+public abstract class AbstractXhtml5Sink extends SinkAdapter {}
