@@ -1,5 +1,3 @@
-package org.apache.maven.doxia.module.xhtml5;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,19 +16,18 @@ package org.apache.maven.doxia.module.xhtml5;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.doxia.module.xhtml5;
 
 import org.apache.maven.doxia.markup.HtmlMarkup;
 
 /**
- * List of <code>Xhtml</code> markups.
+ * List of <code>Xhtml5</code> markups.
  * <br>
- * Xhtml uses all {@link javax.swing.text.html.HTML.Tag} and {@link javax.swing.text.html.HTML.Attribute}
+ * Xhtml5 uses all {@link javax.swing.text.html.HTML.Tag} and {@link javax.swing.text.html.HTML.Attribute}
  * as markups.
  */
-@SuppressWarnings( "checkstyle:interfaceistype" )
-public interface Xhtml5Markup
-    extends HtmlMarkup
-{
+@SuppressWarnings("checkstyle:interfaceistype")
+public interface Xhtml5Markup extends HtmlMarkup {
     /** XHTML5 namespace: "http://www.w3.org/1999/xhtml" */
     String XHTML5_NAMESPACE = "http://www.w3.org/1999/xhtml";
 }
