@@ -1,5 +1,3 @@
-package org.apache.maven.doxia.module.xhtml5;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -18,23 +16,23 @@ package org.apache.maven.doxia.module.xhtml5;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.doxia.module.xhtml5;
+
+import javax.inject.Named;
+import javax.inject.Singleton;
 
 import org.apache.maven.doxia.parser.module.AbstractParserModule;
-import org.apache.maven.doxia.parser.module.ParserModule;
-import org.codehaus.plexus.component.annotations.Component;
 
 /**
  * <p>Xhtml5ParserModule class.</p>
  */
-@Component( role = ParserModule.class, hint = "xhtml5" )
-public class Xhtml5ParserModule
-    extends AbstractParserModule
-{
+@Singleton
+@Named("xhtml")
+public class Xhtml5ParserModule extends AbstractParserModule {
     /**
      * Default constructor.
      */
-    public Xhtml5ParserModule()
-    {
-        super( "xhtml5" );
+    public Xhtml5ParserModule() {
+        super("xhtml");
     }
 }
